/* VC */

#include <fstream>
#include <vector>
#include <cmath>
#include <set>

using namespace std;

struct Vector2
{
    double x,y;
    Vector2() {x = 0;y = 0;}
    Vector2(double x,double y)
    {
        this->x = x;
        this->y = y;
    }
};

Vector2 operator +(Vector2 p1,Vector2 p2)
{
    return Vector2(p1.x+p2.x,p1.y+p2.y);
}

Vector2 operator -(Vector2 p1,Vector2 p2)
{
    return Vector2(p1.x-p2.x,p1.y-p2.y);
}

Vector2 operator *(double factor,Vector2 v)
{
    return Vector2(factor*v.x,factor*v.y);
}

Vector2 operator /(Vector2 v,double factor)
{
    return Vector2(v.x/factor,v.y/factor);
}

bool operator !=(Vector2 p1,Vector2 p2)
{
    return p1.x != p2.x ||
           p1.y != p2.y;
}

int gcd(int a,int b)
{
    while(true)
    {
        if(a == 0)
            return b;
        b %= a;
        if(b == 0)
            return a;
        a %= b;
    }
}

std::pair<int,int> fraction(double f)
{
    int m = f;
    int n = 1;
    while(m != (int)m)
    {
        m *= 10;
        n *= 10;
    }
    return std::make_pair(m/gcd(m,n),n/gcd(m,n));
}

struct Line2
{
    double a,b,c;
    Line2() {a = 0;b = 0;c = 0;}
    Line2(Vector2 p1,Vector2 p2)
    {
        if(p1.x == p2.x)
        {
            a = 1;
            b = 0;
            c = -p1.x;
        }
        else
        {
            a = (p1-p2).y/(p1-p2).x;
            b = -1;
            c = -(a*p1.x+b*p1.y);
        }
        int n1 = fraction(c).second;
        int n2 = fraction(a).second;
        int n = n1*n2/gcd(n1,n2);
        a *= n;
        b *= n;
        c *= n;
        if(a < 0)
        {
            a *= -1;
            b *= -1;
            c *= -1;
        }
        if(a == 0 && b < 0)
        {
            b *= -1;
            c *= -1;
        }
    }
};

Vector2 intersection(Line2 l1,Line2 l2)
{
    if(l1.a*l2.b - l2.a*l1.b != 0)
    {
        double x = (l1.c*l2.b - l2.c*l1.b)/(l1.a*l2.b - l2.a*l1.b);
        double y;
        if(l1.b != 0)
            y = (l1.c - l1.a*x)/l1.b;
        else
            y = (l2.c - l2.a*x)/l2.b;
        return Vector2(x,y);
    }
    else
        return Vector2(-1,-1);
}

double distance(Vector2 p,Line2 l)
{
    return abs(l.a*p.x+l.b*p.y+l.c)/sqrt(l.a*l.a+l.b*l.b);
}

double sum(const std::vector<Line2>& way,Vector2 point)
{
    double answer = 0;
    for(int i = 0;i < way.size();i++)
        answer += distance(point,way[i]);
    return answer;
}

int main()
{
    std::ifstream in("motel.in");
    int n;
    in >> n;
    std::vector<Line2> way(n);
    for(int i = 0;i < way.size();i++)
    {
        Vector2 p1,p2;
        in >> p1.x >> p1.y >> p2.x >> p2.y;
        way[i] = Line2(p1,p2);
    }
    in.close();
    std::vector<Vector2> point;
    bool collinear = false;
    for(int i = 0;i < way.size();i++)
    {
        for(int j = i+1;j < way.size();j++)
        {
            if(intersection(way[i],way[j]) != Vector2(-1,-1))
                point.push_back(intersection(way[i],way[j]));
            else
                collinear = true;
        }
    }
    std::ofstream out("motel.out");
    if(!collinear)
    {
        std::set<std::pair<double,int> > ordered;
        for(int i = 0;i < point.size();i++)
            ordered.insert(std::make_pair(sum(way,point[i]),i));
        int count = 1;
        for(std::set<std::pair<double,int> >::iterator i = ordered.begin();
            i != ordered.end();i++)
            if(i->first == ordered.begin()->first)
                count++;
        out << count << std::endl;
        std::pair<int,int> answer = fraction(ordered.begin()->first);
        out << answer.first;
        if(answer.second != 1)
            out << "/" << answer.second;
        out << std::endl;
        out << count << std::endl;
        for(std::set<std::pair<double,int> >::iterator i = ordered.begin();
            i != ordered.end();i++)
        {
            if(i->first == ordered.begin()->first)
            {
                Vector2 current = point[i->second];
                std::pair<int,int> x = fraction(current.x);
                out << x.first;
                if(x.second != 1)
                    out << "/" << x.second;
                out << ' ';
                std::pair<int,int> y = fraction(current.y);
                out << y.first;
                if(y.second != 1)
                    out << "/" << x.second;

                out << std::endl;
            }
        }
    }
    out.close();
}
